api/pagarme_api library

This class sends an HTTP request to Pagar.me's API endpoint that is responsible for generating the RSA key that is used to encrypt the card data to be sent to your backend (and Pagar.me's API)

Classes

PagarMeApi<T>