HttpTunnel<T> class

Constructors

HttpTunnel()

Properties

dio → Dio
final
hashCode int
The hash code for this object.
no setterinherited
options ↔ Options
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
getter/setter pair

Methods

delete(String url, dynamic data) Future<Response<T>>
get(String url) Future<Response<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String url, dynamic data) Future<Response<T>>
post(String url, dynamic data) Future<Response<T>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited