JsonUtils class

This class is responsible for kinda parsing the json data contained in the response returned from Pagar.me's API endpoint.

Constructors

JsonUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOrThis(dynamic defaultValue, dynamic key, Map<String, dynamic> json) → dynamic