ResponseException class
This class is just a generic exception class for request/response related issues.
- Implemented types
Constructors
- ResponseException({String? cause})
Properties
Methods
-
getCause(
) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited